3.4 Command Arguments
=====================

Type: Args (Map)

.. list-table::
   :widths: 3 4 4 3 40
   :header-rows: 1

   * - ID
     - Name
     - Type
     - #
     - Description
   * - 4
     - response_requested
     - :py:class:`~otupy.types.data.response_type.ResponseType`
     - 0
     - The type of Response required for the Command: none, ack, status, complete.
   * - 2
     - name_only
     - ``bool``
     - 0
     - The response includes either only the name or all the details about the services and the links. (This will likely be remoted or replaced by the :py:class:`~otupy.profiles.ctxd.data.service.SId` in future releases)
   * - 3
     - cached
     - ``bool``
     - 0
     - If set, this flag asks to return cached info, without updating it from the authoritative source (faster to run, but may return outdated data). To be used for testing purposes. 

Command Arguments are optional, and a new one called “name_only” has
been defined, which is not present in the Language Specification.

Usage requirements:
-------------------

-  The “response_requested”: “complete” argument can be present in the
   “query features” Command. (Language specification 4.1)
-  The “query context” Command may include the “response_requested”:
   “complete” Argument.
-  The “query context” command may include the “name_only” argument:

   -  If TRUE, the Consumer must send a Response containing only the
      names of the services and/or links.
   -  If FALSE, the Consumer must send a Response containing all the
      details of the services and/or links.

